summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/main.c18
-rw-r--r--src/qr-show.c6
2 files changed, 12 insertions, 12 deletions
diff --git a/src/qr-show.c b/src/qr-show.c
index 728b9ca..d73cd5a 100644
--- a/src/qr-show.c
+++ b/src/qr-show.c
@@ -101,7 +101,7 @@ static char *const *arg_next;
static struct GNUNET_TIME_Relative delay;
/**
- * Refenence to the delay task
+ * Reference to the delay task
*/
static struct GNUNET_SCHEDULER_Task *delay_task;
@@ -259,7 +259,7 @@ shutdown_task (void *cls)
&qrDisplay.orig_vinfo))
{
GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
- "failed to reset originial display state\n");
+ "failed to reset original display state\n");
}
/* close device */
close (qrDisplay.devicefd);
@@ -277,7 +277,7 @@ shutdown_task (void *cls)
* @param cls closure
* @param args arguments left
* @param cfgfile config file name
- * @param cfg handle for the configuation file
+ * @param cfg handle for the configuration file
*/
static void
run (void *cls,
diff --git a/src/main.c b/src/main.c
index 0eb3eb9..e43881d 100644
--- a/src/main.c
+++ b/src/main.c
@@ -112,12 +112,12 @@ along with
/* upper and lower bounds for mifare targets uid length */
/**
- * Upper lenght of the uid for a valid MIFARE target
+ * Upper length of the uid for a valid MIFARE target
*/
#define UID_LEN_UPPER 7
/**
- * Lower lenght of the uid for a valid MIFARE target
+ * Lower length of the uid for a valid MIFARE target
*/
#define UID_LEN_LOWER 4
@@ -612,7 +612,7 @@ static char *backend_base_url;
static char *fulfillment_url;
/**
- * Fulfillment message to display after successfull payment, read from configuration file
+ * Fulfillment message to display after successful payment, read from configuration file
*/
static char *fulfillment_msg;
@@ -1295,7 +1295,7 @@ connect_target (void *cls)
GNUNET_log (GNUNET_ERROR_TYPE_INFO,
"Failed to connect to NFC target\n");
}
- /* if the uid lenght are out of bound abort */
+ /* if the uid length are out of bound abort */
else if ( (pa->nt.nti.nai.szUidLen > UID_LEN_UPPER) ||
(pa->nt.nti.nai.szUidLen < UID_LEN_LOWER) )
{
@@ -2487,7 +2487,7 @@ read_mdb_command (void *cls)
while (mdb.rx_off > 0)
{
mdb_active = GNUNET_YES;
/* find begining of command */
for (cmdStartIdx = 0; cmdStartIdx < mdb.rx_off; cmdStartIdx++)
if (VMC_CMD_START == mdb.rxBuffer[cmdStartIdx])
break;
@@ -2550,7 +2550,7 @@ run_mdb_event_loop ()
(NULL == mdb.last_cmd) )
{
GNUNET_log (GNUNET_ERROR_TYPE_INFO,
- "Begining MDB session\n");
+ "Beginning MDB session\n");
mdb.cmd = &cmd_begin_session;
}
/* start write task if he doesn't exist and if there is a cmd waiting to get sent */
@@ -2650,7 +2650,7 @@ read_products (void *cls,
GNUNET_log_config_invalid (GNUNET_ERROR_TYPE_ERROR,
section,
"price",
- "currency missmatch");
+ "currency mismatch");
GNUNET_free (tmpProduct.description);
return;
}
@@ -2852,7 +2852,7 @@ mdb_init ()
"tcsetattr");
return GNUNET_SYSERR;
}
- /* if the configuration of the uart was sucessfull start the mdb write and read tasks */
+ /* if the configuration of the uart was successful start the mdb write and read tasks */
run_mdb_event_loop ();
return GNUNET_OK;
}
@@ -2864,7 +2864,7 @@ mdb_init ()
* @param cls closure
* @param args arguments left
* @param cfgfile config file name
- * @param cfg handle for the configuation file
+ * @param cfg handle for the configuration file
*/
static void
run (void *cls,
@@ -2487,7 +2487,7 @@ read_mdb_command (void *cls)
{
mdb_active = GNUNET_YES;
- /* find begining of command */
+ /* find beginning of command */
for (cmdStartIdx = 0; cmdStartIdx < mdb.rx_off; cmdStartIdx++)
if (VMC_CMD_START == mdb.rxBuffer[cmdStartIdx])